==> v8.3.zip: ru_twords_ru_tw/bible/names/balaam.md <==
# Валаам

## Факты:

Валаам — языческий пророк, которого царь Валаак нанял, чтобы он проклял Израиль, расположившийся лагерем у реки Иордан в северном Моаве, готовясь к вторжению в землю ханаанскую.

* Валаам был из города Пефора, расположенного в местности у реки Евфрат, на расстоянии более четырёхсот километров от моавитской земли.
* Мадиамский царь Валаак испугался численности и силы израильтян, поэтому он нанял Валаама, чтобы тот проклял их.
* Когда Валаам двинулся в сторону Израиля, Божий ангел преградил ему путь, и ослица Валаама остановилась. Бог дал ослице способность говорить с Валаамом.
* Бог не позволил Валааму проклинать израильтян, наоборот, Он велел благословить их.
* Однако позже Валаам всё же навёл беду на израильтян, склонив их к поклонению лжебогу Ваал-Фегору.

(Варианты перевода: [Как переводить имена](rc://*/ta/man/translate/translate-names))

(См. также: [благословлять, благословенный, блаженный благословение](../kt/bless.md), [Ханаан, хананей](../names/canaan.md), [проклятие, проклинать, проклятый](../kt/curse.md), [осел, мул](../other/donkey.md), [Евфрат](../names/euphrates.md), [Река Иордан](../names/jordanriver.md), [Мадиам, мадианитяне](../names/midian.md), [Моав, моавитянин, моавитянка](../names/moab.md), [Фегор, гора Фегор, Ваал Фегор](../names/peor.md))

## Ссылки на библейский текст:

* [2 Пет. 2:15-16](rc://*/tn/help/2pe/02/15)
* [Втор. 23:3-4](rc://*/tn/help/deu/23/03)
* [Нав. 13:22-23](rc://*/tn/help/jos/13/22)
* [Чис. 22:5-6](rc://*/tn/help/num/22/05)
* [Откр. 2:14-15](rc://*/tn/help/rev/02/14)

## Данные о слове:

* Номера Стронга: H1109, G903

==> v9.2.zip: ru_twords_ru_tw/bible/names/balaam.md <==
# Валаам

## Факты:

Валаам — языческий пророк, которого царь Валаак нанял, чтобы он проклял Израиль, расположившийся лагерем у реки Иордан в северном Моаве, готовясь к вторжению в землю ханаанскую.

* Валаам был из города Пефора, расположенного в местности у реки Евфрат, на расстоянии более четырёхсот километров от моавитской земли.
* Мадиамский царь Валаак испугался численности и силы израильтян, поэтому он нанял Валаама, чтобы тот проклял их.
* Когда Валаам двинулся в сторону Израиля, Божий ангел преградил ему путь, и ослица Валаама остановилась. Бог дал ослице способность говорить с Валаамом.
* Бог не позволил Валааму проклинать израильтян, наоборот, Он велел благословить их.
* Однако позже Валаам всё же навёл беду на израильтян, склонив их к поклонению лжебогу Ваал-Фегору.

(Варианты перевода: [Как переводить имена](rc://ru/ta/man/translate/translate-names))

(См. также: [благословлять, благословенный, блаженный благословение](../kt/bless.md), [Ханаан, хананей](../names/canaan.md), [проклятие, проклинать, проклятый](../kt/curse.md), [осел, мул](../other/donkey.md), [Евфрат](../names/euphrates.md), [Река Иордан](../names/jordanriver.md), [Мадиам, мадианитяне](../names/midian.md), [Моав, моавитянин, моавитянка](../names/moab.md), [Фегор, гора Фегор, Ваал Фегор](../names/peor.md))

## Ссылки на библейский текст:

* [2 Пет. 2:15-16](rc://ru/tn/help/2pe/02/15)
* [Втор. 23:3-4](rc://ru/tn/help/deu/23/03)
* [Нав. 13:22-23](rc://ru/tn/help/jos/13/22)
* [Чис. 22:5-6](rc://ru/tn/help/num/22/05)
* [Откр. 2:14-15](rc://ru/tn/help/rev/02/14)

## Данные о слове:

* Номера Стронга: H1109, G903
